#!/bin/bash

Help()
{
  msg="
A utility script to see the contents of the Container.tar generated by App2Container
without extracting it to help find files or folder that are of large sizes and can be excluded
  -p path to the Container.tar
  -d depth of the path to consider
  -s size of the file to consider
  -t toplevel of the directory
  -f filetype to filter
  -v print the size of each folder
  -h help"
  printf "$msg"
}

#set Defaults values
depth=1
size=0
toplevel="/"
verbose=0
filetype=""

#Read options
while getopts ":p:d:s:t:f:vh" opt; do
  case ${opt} in
    h )
      Help
      exit 0
      ;;
    p )
      path=$OPTARG
      ;;
    d )
      depth=$OPTARG
      ;;
    s )
      size=$OPTARG
      ;;
    t )
      toplevel=$OPTARG
      ;;
    f )
      filetype=\\\.$OPTARG
      ;;
    v )
      verbose=1
      ;;
    \? )
      echo "Invalid option: $OPTARG" 1>&2
      Help
      exit
      ;;
    : )
      echo "Invalid option: $OPTARG requires an argument" 1>&2
      Help
      exit
      ;;
  esac
done

if test -f "$path"; then
    echo "$path exists."
else
    echo "$path does not exist."
    exit
fi

#increment the depth by 1
(( depth = depth + 1 ))

# Since toplevel and filetype is a , seperated list.
# Replace the / with \/
# Replace the , with |^ to create regex per path provided.
toplevel=`echo $toplevel | sed 's/\//\\\\\\//g'| sed 's/,/|^/g'`

# Replace the , with $|\\\. to create regex per filetype provided.
filetype=`echo $filetype | sed 's/,/$|\\\./g'`

#if the file size is above the size then sum and store the same on the index.
#print the array and size in verbose mode.
awk_cmd="awk '{ if (\$1>= $size) arr[\$2]+=\$1 } END { \
for (key in arr) {
  if($verbose)
    printf(\"%-50s\t%-50s\n\", key, arr[key])
  else
    printf(\"%s,\n\", key)
  }
}
'"

#use tar -tvf to list the files.Trim the spaces and then extract column 5 and 9.
#filter the file path which ends with filetype
#filter the file path which starts with toplevel directory
#cut based on "/" and then extract columns based on the depth
#pipe the same to the awk commandgit di
cmd="tar -Ptvf $path|tr -s ' '|cut -d ' ' -f3,6| awk '\$2 ~/$filetype$/'| awk '\$2 ~/^$toplevel/' |cut -f1-$depth -d'/'|$awk_cmd|sort -k2 -nr"
echo $cmd

echo "==============================================================================================="
eval "$cmd"


